from django.shortcuts import render
from books.book_store import books_list, book_info, book_text
from django.conf import settings

from django.http import Http404
import os

# Create your views here.
def main_view(request):
    files = books_list(settings.FILES_DIR)
    result = []
    for file_name in files:
        (title, author, annot) = book_info(os.path.join(settings.FILES_DIR, file_name))
        book_obj = {
            "file_name": file_name,
            "title": title,
            "annot": annot,
        }
        result.append(book_obj)
    context = {
        "items": result,
    }
    return render(request, "main.html", context)

def book_view(request, book_id):
    full_file_name = os.path.join(settings.FILES_DIR, book_id)
    try:
        (title, author, annot) = book_info(full_file_name)
        text = book_text(full_file_name)
    except FileNotFoundError:
        raise Http404
    context = {
        "book_title": title,
        "book_annot": annot,
        "book_text": text,
    }
    return render(request, "book.html", context)
